@@ -12,6 +12,9 @@ class UpdateType(str, Enum):
     update_cells = 'update_cells'
     new_index = 'update_index'
     new_df = 'new_df'
+    # this is used for users to force an update so the dataframe will be reloaded,
+    # used for the type of dataframe that can not automatically track the updates
+    forced_update = 'forced_update'
     # `no_update` is introduced to make it easy to update the case where update might be external.
     no_update = 'no_update'
     # Need to improve this.
@@ -20,6 +23,10 @@ class UpdateType(str, Enum):
         return str(self.value)
 
 
+# running line value used in the case that variable is forced to be updated. see forced_update above
+FORCED_UPDATE_RUNNING_LINE = -1
+
+
 class DataFrameUpdate(JsonSerializable):
     def __init__(self, update_type: UpdateType, updates: list = []):
         self.update_type = update_type
@@ -29,7 +36,7 @@ class DataFrameUpdate(JsonSerializable):
 class DataFrameOp(JsonSerializable):
     def __init__(self, name: str = '', *args, **kwargs):
         """A Dataframe Operation
-           Since args and kwargs are only for the record here, we keep it as string 
+           Since args and kwargs are only for the record here, we keep it as string
            to avoid json serializable problem with slice
         Args:
             name (str): op's name
@@ -39,3 +46,10 @@ class DataFrameOp(JsonSerializable):
         self.name = name
         # self.args = str(args)
         # self.kargs = str(kwargs)
+
+
+def get_class_fullname(klass):
+    module = klass.__module__
+    if module == 'builtins':
+        return klass.__qualname__
+    return module + '.' + klass.__qualname__
