@@ -63,12 +63,17 @@ class CnextMimeType(str, Enum):
     FILE_PNG = 'file/png'
     FILE_JPG = 'file/jpg'
     FILE_JPEG = 'file/jpeg'
+    FILE_IMAGE = 'file/image'
     IMAGE_PNG = 'image/png'
     IMAGE_JPG = 'image/jpg'
     IMAGE_JPEG = 'image/jpeg'
     URL_PNG = 'url/png'
     URL_JPG = 'url/jpg'
     URL_JPEG = 'url/jpeg'
+    URL_IMAGE = 'url/image'
+    INPUT_SELECTION = "input/selection"
+    INPUT_CHECKBOX = "input/checkbox"
+    INPUT_TEXT = "input/text"
 
     def __str__(self):
         return str(self.value)
@@ -84,7 +89,7 @@ class MimeDtypeType(type):
 
 
 @register_extension_dtype
-class FileMimeDtype(ExtensionDtype):
+class FilePngMimeDtype(ExtensionDtype):
     type = MimeDtypeType
     name = CnextMimeType.FILE_PNG
 
@@ -115,7 +120,7 @@ class FileMimeDtype(ExtensionDtype):
         """
         # from pandas.core.arrays.string_ import FileMimeArray
 
-        return FileMimeArray
+        return FilePngMimeArray
 
     def __hash__(self) -> int:
         # custom __eq__ so have to override __hash__
@@ -126,8 +131,8 @@ class BaseFileMimeArray(ExtensionArray):
     pass
 
 
-class FileMimeArray(BaseFileMimeArray, PandasArray):
-    dtype_class = FileMimeDtype
+class FilePngMimeArray(BaseFileMimeArray, PandasArray):
+    dtype_class = FilePngMimeDtype
     # undo the PandasArray hack
     _typ = "extension"
 
@@ -167,18 +172,18 @@ class FileMimeArray(BaseFileMimeArray, PandasArray):
             result = scalars._data
             result = lib.ensure_string_array(
                 result, copy=copy, convert_na_value=False)
-            result[na_values] = FileMimeDtype.na_value
+            result[na_values] = FilePngMimeDtype.na_value
 
         else:
             # convert non-na-likes to str, and nan-likes to FilePathMimeDtype.na_value
             result = lib.ensure_string_array(
-                scalars, na_value=FileMimeDtype.na_value, copy=copy
+                scalars, na_value=FilePngMimeDtype.na_value, copy=copy
             )
 
         # Manually creating new array avoids the validation step in the __init__, so is
         # faster. Refactor need for validation?
         new_string_array = cls.__new__(cls)
-        NDArrayBacked.__init__(new_string_array, result, FileMimeDtype())
+        NDArrayBacked.__init__(new_string_array, result, FilePngMimeDtype())
 
         return new_string_array
 
@@ -189,7 +194,7 @@ class FileMimeArray(BaseFileMimeArray, PandasArray):
         return cls._from_sequence(strings, dtype=dtype, copy=copy)
 
     @classmethod
-    def _empty(cls, shape, dtype) -> FileMimeArray:
+    def _empty(cls, shape, dtype) -> FilePngMimeArray:
         values = np.empty(shape, dtype=object)
         values[:] = libmissing.NA
         return cls(values).astype(dtype, copy=False)
@@ -228,7 +233,7 @@ class FileMimeArray(BaseFileMimeArray, PandasArray):
         # validate new items
         if scalar_value:
             if isna(value):
-                value = FileMimeDtype.na_value
+                value = FilePngMimeDtype.na_value
             elif not isinstance(value, str):
                 raise ValueError(
                     f"Cannot set non-string value '{value}' into a FileMimeArray."
@@ -308,7 +313,7 @@ class FileMimeArray(BaseFileMimeArray, PandasArray):
     def _cmp_method(self, other, op):
         from pandas.arrays import BooleanArray
 
-        if isinstance(other, FileMimeArray):
+        if isinstance(other, FilePngMimeArray):
             other = other._ndarray
 
         mask = isna(self) | isna(other)
@@ -326,7 +331,7 @@ class FileMimeArray(BaseFileMimeArray, PandasArray):
 
         if op.__name__ in ops.ARITHMETIC_BINOPS:
             result = np.empty_like(self._ndarray, dtype="object")
-            result[mask] = FileMimeDtype.na_value
+            result[mask] = FilePngMimeDtype.na_value
             result[valid] = op(self._ndarray[valid], other)
             return self.dtype_class(result)
         else:
@@ -339,7 +344,7 @@ class FileMimeArray(BaseFileMimeArray, PandasArray):
 
     # ------------------------------------------------------------------------
     # String methods interface
-    _str_na_value = FileMimeDtype.na_value
+    _str_na_value = FilePngMimeDtype.na_value
 
     def _str_map(
         self, f, na_value=None, dtype: Dtype | None = None, convert: bool = True
@@ -347,7 +352,7 @@ class FileMimeArray(BaseFileMimeArray, PandasArray):
         from pandas.arrays import BooleanArray
 
         if dtype is None:
-            dtype = FileMimeDtype(storage="python")
+            dtype = FilePngMimeDtype(storage="python")
         if na_value is None:
             na_value = self.dtype.na_value
 
@@ -408,7 +413,7 @@ class FileMimeArray(BaseFileMimeArray, PandasArray):
 
 
 @register_extension_dtype
-class URLMimeDtype(FileMimeDtype):
+class URLPngMimeDtype(FilePngMimeDtype):
     name = CnextMimeType.URL_PNG
 
     # @classmethod
@@ -419,8 +424,105 @@ class URLMimeDtype(FileMimeDtype):
         -------
         type
         """
-        return URLMimeArray
+        return URLPngMimeArray
+
+
+class URLPngMimeArray(FilePngMimeArray):
+    dtype_class = URLPngMimeDtype
+
+
+@register_extension_dtype
+class FileJpgMimeDtype(FilePngMimeDtype):
+    name = CnextMimeType.FILE_JPG
+
+    # @classmethod
+    def construct_array_type(cls):
+        """
+        Return the array type associated with this dtype.
+        Returns
+        -------
+        type
+        """
+        return FileJpgMimeArray
+
+
+class FileJpgMimeArray(FilePngMimeArray):
+    dtype_class = FileJpgMimeDtype
+
+
+@register_extension_dtype
+class URLJpgMimeDtype(FilePngMimeDtype):
+    name = CnextMimeType.URL_JPG
+
+    # @classmethod
+    def construct_array_type(cls):
+        """
+        Return the array type associated with this dtype.
+        Returns
+        -------
+        type
+        """
+        return URLJpgMimeArray
+
+
+class URLJpgMimeArray(FilePngMimeArray):
+    dtype_class = URLJpgMimeDtype
+
+
+@register_extension_dtype
+class InputSelectionMimeDtype(FilePngMimeDtype):
+    name = CnextMimeType.INPUT_SELECTION
+
+    # @classmethod
+    def construct_array_type(cls):
+        """
+        Return the array type associated with this dtype.
+        Returns
+        -------
+        type
+        """
+        return InputSelectionMimeArray
+
+
+class InputSelectionMimeArray(FilePngMimeArray):
+    dtype_class = InputSelectionMimeDtype
+
+
+@register_extension_dtype
+class InputCheckboxMimeDtype(FilePngMimeDtype):
+    name = CnextMimeType.INPUT_CHECKBOX
+
+    # @classmethod
+    def construct_array_type(cls):
+        """
+        Return the array type associated with this dtype.
+        Returns
+        -------
+        type
+        """
+        return InputCheckboxMimeArray
+
+
+class InputCheckboxMimeArray(FilePngMimeArray):
+    dtype_class = InputCheckboxMimeDtype
+
+
+@register_extension_dtype
+class InputTextMimeDtype(FilePngMimeDtype):
+    name = CnextMimeType.INPUT_TEXT
+
+    # @classmethod
+    def construct_array_type(cls):
+        """
+        Return the array type associated with this dtype.
+        Returns
+        -------
+        type
+        """
+        return InputTextMimeArray
+
+
+class InputTextMimeArray(FilePngMimeArray):
+    dtype_class = InputTextMimeDtype
 
 
-class URLMimeArray(FileMimeArray):
-    dtype_class = URLMimeDtype
